@@ -7,6 +7,7 @@
 
 import time
 import os
+import json
 import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
@@ -22,6 +23,7 @@ from .core import graph_from_point
 from .core import bbox_from_point
 from .projection import project_graph
 from .save_load import graph_to_gdfs
+from .settings import default_crs
 from .simplify import simplify_graph
 from .utils import log
 
@@ -416,6 +418,12 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02,
         # make everything square
         ax.set_aspect('equal')
         fig.canvas.draw()
+    else:
+        # if the graph is not projected, conform the aspect ratio to not stretch the plot
+        if G.graph['crs'] == default_crs:
+            coslat = np.cos((min(node_Ys) + max(node_Ys)) / 2. / 180. * np.pi)
+            ax.set_aspect(1. / coslat)
+            fig.canvas.draw()
 
     # annotate the axis with node IDs if annotate=True
     if annotate:
@@ -610,7 +618,9 @@ def make_folium_polyline(edge, edge_color, edge_width, edge_opacity, popup_attri
         raise ImportError('The folium package must be installed to use this optional feature.')
 
     # locations is a list of points for the polyline
-    locations = list(edge['geometry'].coords)
+    # folium takes coords in lat,lon but geopandas provides them in lon,lat
+    # so we have to flip them around
+    locations = list([(lat, lon) for lon, lat in edge['geometry'].coords])
 
     # if popup_attribute is None, then create no pop-up
     if popup_attribute is None:
@@ -618,11 +628,11 @@ def make_folium_polyline(edge, edge_color, edge_width, edge_opacity, popup_attri
     else:
         # folium doesn't interpret html in the html argument (weird), so can't
         # do newlines without an iframe
-        popup_text = str(edge[popup_attribute])
+        popup_text = json.dumps(edge[popup_attribute])
         popup = folium.Popup(html=popup_text)
 
     # create a folium polyline with attributes
-    pl = folium.PolyLine(locations=locations, popup=popup, latlon=False,
+    pl = folium.PolyLine(locations=locations, popup=popup,
                          color=edge_color, weight=edge_width, opacity=edge_opacity)
     return pl
 
