@@ -10,6 +10,7 @@ import math
 import numpy as np
 import geopandas as gpd
 import networkx as nx
+from .settings import default_crs
 from shapely.geometry import Point
 
 from .utils import log
@@ -27,7 +28,7 @@ def project_geometry(geometry, crs=None, to_crs=None, to_latlong=False):
         the geometry to project
     crs : dict
         the starting coordinate reference system of the passed-in geometry,
-        default value (None) will set EPSG:4326 as the CRS
+        default value (None) will set settings.default_crs as the CRS
     to_crs : dict
         if not None, just project to this CRS instead of to UTM
     to_latlong : bool
@@ -42,7 +43,7 @@ def project_geometry(geometry, crs=None, to_crs=None, to_latlong=False):
     """
 
     if crs is None:
-        crs = {'init':'epsg:4326'}
+        crs = default_crs
 
     gdf = gpd.GeoDataFrame()
     gdf.crs = crs
@@ -92,9 +93,9 @@ def project_gdf(gdf, to_crs=None, to_latlong=False):
     else:
         if to_latlong:
             # if to_latlong is True, project the gdf to latlong
-            latlong_crs = {'init':'epsg:4326'}
+            latlong_crs = default_crs
             projected_gdf = gdf.to_crs(latlong_crs)
-            log('Projected the GeoDataFrame "{}" to EPSG 4326 in {:,.2f} seconds'.format(gdf.gdf_name, time.time()-start_time))
+            log('Projected the GeoDataFrame "{}" to default_crs in {:,.2f} seconds'.format(gdf.gdf_name, time.time()-start_time))
         else:
             # else, project the gdf to UTM
             # if GeoDataFrame is already in UTM, just return it
@@ -108,8 +109,8 @@ def project_gdf(gdf, to_crs=None, to_latlong=False):
             # calculate the UTM zone from this avg longitude and define the UTM
             # CRS to project
             utm_zone = int(math.floor((avg_longitude + 180) / 6.) + 1)
-            utm_crs = {'datum': 'NAD83',
-                       'ellps': 'GRS80',
+            utm_crs = {'datum': 'WGS84',
+                       'ellps': 'WGS84',
                        'proj' : 'utm',
                        'zone' : utm_zone,
                        'units': 'm'}
